@@ -140,12 +140,20 @@ register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMB6PBN')
 register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMB2PBN')
 register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMB6PBB')
 register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBGP1')
+register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBEL1')
+register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBGP1-2')
 register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBGP2')
+register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBEL2')
+register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBGP2-2')
 register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBGP4')
+register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBEL4')
+register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBGP4-2')
 register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBGPO')
 register_command(COMMAND_CODE, ModuleStatusMessage2, 'SUB_VMBGPO')
 register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBGPOD')
 register_command(COMMAND_CODE, ModuleStatusMessage2, 'SUB_VMBGPOD')
+register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBELO')
+register_command(COMMAND_CODE, ModuleStatusMessage2, 'SUB_VMBELO')
 register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMB7IN')
 register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMB4DC')
 register_command(COMMAND_CODE, ModuleStatusMessage2, 'VMBDME')
