@@ -20,7 +20,7 @@ class VMBIROModule(Module):
     def getMinTemp(self):
         return self._min
 
-    def getMiaxTemp(self):
+    def getMaxTemp(self):
         return self._max
 
     def getCurTemp(self):
